import type { Mapper } from "@siteimprove/alfa-mapper";
import type { Result } from "@siteimprove/alfa-result";
import { Err, Ok } from "@siteimprove/alfa-result";
import { Unit } from "../../unit/index.js";
import type { Numeric } from "../numeric/index.js";
import { Angle, Length, Number, Percentage } from "../numeric/index.js";
import { Expression } from "./expression.js";
import { Kind } from "./kind.js";
/**
 * @public
 */
export declare class Value<N extends Numeric = Numeric> extends Expression {
    static of<N extends Numeric = Numeric>(value: N, kindHint?: Kind): Value<N>;
    private readonly _value;
    protected constructor(value: N, kind: Kind);
    get value(): N;
    reduce(this: Value<Angle>, resolver: Expression.Resolver): Value<Angle<Unit.Angle.Canonical>>;
    reduce<L extends Unit.Length = Unit.Length.Canonical>(this: Value<Length>, resolver: Expression.Resolver<L>): Value<Length<Unit.Length.Canonical | L>>;
    reduce(this: Value<Number>, resolver: Expression.Resolver): Value<Number>;
    reduce<L extends Unit.Length = Unit.Length.Canonical, P extends Numeric = Numeric>(this: Value<Percentage>, resolver: Expression.Resolver<L, P>): Value<P>;
    toAngle(): Result<Angle, string>;
    toLength(): Result<Length, string>;
    toNumber(this: Value<Number>): Ok<Number>;
    toNumber(this: Value<Exclude<Numeric, Number>>): Err<string>;
    toPercentage(): Result<Percentage, string>;
    simplify(): Value;
    isCanonical(): boolean;
    equals(value: unknown): value is this;
    toJSON(): Value.JSON;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Value {
    interface JSON extends Expression.JSON {
        type: "value";
        value: Numeric.JSON;
    }
    function isValueExpression(value: unknown): value is Value;
    /**
     * @internal
     */
    function angleResolver(angle: Angle): Angle<Unit.Angle.Canonical>;
    /**
     * @internal
     */
    function lengthResolver<U extends Unit.Length = Unit.Length.Canonical>(resolver: Mapper<Length<Unit.Length.Relative>, Length<U>>): Mapper<Length, Length<Unit.Length.Canonical> | Length<U>>;
}
//# sourceMappingURL=value.d.ts.map