import type { Equatable } from "@siteimprove/alfa-equatable";
import type { Hash, Hashable } from "@siteimprove/alfa-hash";
import type { Serializable } from "@siteimprove/alfa-json";
import type * as json from "@siteimprove/alfa-json";
/**
 * @public
 */
export declare abstract class Numeric<T extends Numeric.Type = Numeric.Type> implements Equatable, Hashable, Serializable {
    /**
     * The number of decimals stored for every numeric value.
     */
    static readonly Decimals = 7;
    protected readonly _value: number;
    protected readonly _type: T;
    protected constructor(value: number, type: T);
    get type(): T;
    get value(): number;
    abstract scale(factor: number): Numeric<T>;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): Numeric.JSON<T>;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Numeric {
    interface JSON<T extends Type = Type> {
        [key: string]: json.JSON;
        type: T;
        value: number;
    }
    function isNumeric(value: unknown): value is Numeric;
    /**
     * {@link https://drafts.csswg.org/css-values-4/#numeric-types}
     */
    type Scalar = "integer" | "number";
    /**
     * {@link https://drafts.csswg.org/css-values-4/#numeric-types}
     */
    type Ratio = "percentage";
    /**
     * {@link https://drafts.csswg.org/css-values-4/#lengths}
     * {@link https://drafts.csswg.org/css-values-4/#other-units}
     */
    type Dimension = "angle" | "length";
    /**
     * @internal
     */
    type Type = Scalar | Ratio | Dimension;
}
//# sourceMappingURL=numeric.d.ts.map