import type { Hash } from "@siteimprove/alfa-hash";
import { Iterable } from "@siteimprove/alfa-iterable";
import { type Parser as CSSParser } from "../../../../syntax/index.js";
import type { PartiallyResolvable, Resolvable } from "../../../resolvable.js";
import { Value } from "../../../value.js";
import { Item } from "../item/index.js";
import { Direction } from "./direction.js";
/**
 * {@link https://drafts.csswg.org/css-images/#linear-gradients}
 *
 * @public
 */
export declare class Linear<I extends Item = Item, D extends Direction = Direction> extends Value<"gradient", Value.HasCalculation<[D, I]>> implements Resolvable<Linear.Canonical, Linear.Resolver>, PartiallyResolvable<Linear.PartiallyResolved, Linear.PartialResolver> {
    static of<I extends Item, D extends Direction>(direction: D, items: Iterable<I>, repeats: boolean): Linear<I, D>;
    private readonly _direction;
    private readonly _items;
    private readonly _repeats;
    protected constructor(direction: D, items: Array<I>, repeats: boolean);
    get kind(): "linear";
    get direction(): D;
    get items(): Iterable<I>;
    get repeats(): boolean;
    resolve(resolver: Linear.Resolver): Linear.Canonical;
    partiallyResolve(resolver: Linear.PartialResolver): Linear.PartiallyResolved;
    equals(value: Linear): boolean;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): Linear.JSON;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Linear {
    type Canonical = Linear<Item.Canonical, Direction.Canonical>;
    type PartiallyResolved = Linear<Item.PartiallyResolved, Direction.Canonical>;
    interface JSON extends Value.JSON<"gradient"> {
        kind: "linear";
        direction: Direction.JSON;
        items: Array<Item.JSON>;
        repeats: boolean;
    }
    type Resolver = Item.Resolver & Direction.Resolver;
    type PartialResolver = Item.PartialResolver & Direction.Resolver;
    function isLinear(value: unknown): value is Linear;
    /**
     * {@link https://drafts.csswg.org/css-images/#funcdef-linear-gradient}
     */
    const parse: CSSParser<Linear>;
}
//# sourceMappingURL=linear.d.ts.map