import { Math } from "../../calculation/index.js";
import * as Base from "../../calculation/numeric/index.js";
import { type Parser as CSSParser } from "../../syntax/index.js";
import type { Unit } from "../../unit/index.js";
import type { Resolvable } from "../resolvable.js";
import { Dimension } from "./dimension.js";
import { Angle } from "./angle.js";
import type { Numeric } from "./numeric.js";
import { Percentage } from "./percentage.js";
/**
 * @public
 */
export type AnglePercentage<U extends Unit.Angle = Unit.Angle> = AnglePercentage.Calculated | Angle.Calculated | Angle.Fixed<U> | Percentage.Calculated<"angle"> | Percentage.Fixed<"angle">;
/**
 * @public
 */
export declare namespace AnglePercentage {
    type Canonical = Angle.Canonical;
    /**
     * Angle-percentages that are the result of a calculation.
     */
    class Calculated extends Dimension.Calculated<"angle-percentage"> implements Resolvable<Canonical, never> {
        static of(value: Math<"angle-percentage">): Calculated;
        protected constructor(math: Math<"angle-percentage">);
        hasCalculation(): this is Calculated;
        resolve(resolver?: Numeric.GenericResolver): Canonical;
        equals(value: unknown): value is this;
    }
    namespace Calculated {
        interface JSON extends Dimension.Calculated.JSON<"angle-percentage"> {
        }
    }
    type JSON = Calculated.JSON | Angle.Calculated.JSON | Angle.Fixed.JSON | Percentage.Calculated.JSON | Percentage.Fixed.JSON;
    /**
     * Fully resolves an angle-percentage, when a full resolver is provided.
     */
    function resolve(value: AnglePercentage, resolver?: Numeric.GenericResolver): Canonical;
    function isAnglePercentage(value: unknown): value is AnglePercentage;
    function isCalculated(value: unknown): value is Calculated | Angle.Calculated | Percentage.Calculated;
    function isFixed(value: unknown): value is Angle.Fixed;
    function isPercentage(value: unknown): value is Percentage.Fixed;
    function of<U extends Unit.Angle>(value: number, unit: U): Angle.Fixed<U>;
    function of<U extends Unit.Angle>(value: Base.Angle<U>): Angle.Fixed<U>;
    function of(value: number): Percentage.Fixed;
    function of(value: Base.Percentage): Percentage.Fixed;
    function of(value: Math<"angle">): Angle.Calculated;
    function of(value: Math<"angle-percentage">): Calculated;
    function of(value: Math<"percentage">): Percentage.Calculated;
    /**
     * {@link https://drafts.csswg.org/css-values/#angles}
     */
    const parse: CSSParser<AnglePercentage>;
}
//# sourceMappingURL=angle-percentage.d.ts.map