import type { Hash } from "@siteimprove/alfa-hash";
import { type Parser as CSSParser } from "../../syntax/index.js";
import { Position } from "../position/index.js";
import type { PartiallyResolvable, Resolvable } from "../resolvable.js";
import { Value } from "../value.js";
import { BasicShape } from "./basic-shape.js";
import { Radius } from "./radius.js";
/**
 * {@link https://drafts.csswg.org/css-shapes/#funcdef-ellipse}
 *
 * @public
 */
export declare class Ellipse<R extends Radius = Radius, P extends Position = Position> extends BasicShape<"ellipse", Value.HasCalculation<[R, P]>> implements Resolvable<Ellipse.Canonical, Ellipse.Resolver>, PartiallyResolvable<Ellipse.PartiallyResolved, Ellipse.PartialResolver> {
    static of<R extends Radius = Radius, P extends Position = Position>(rx: R, ry: R, center: P): Ellipse<R, P>;
    private readonly _rx;
    private readonly _ry;
    private readonly _center;
    protected constructor(rx: R, ry: R, center: P);
    get rx(): R;
    get ry(): R;
    get center(): P;
    resolve(resolver: Ellipse.Resolver): Ellipse.Canonical;
    partiallyResolve(resolver: Ellipse.PartialResolver): Ellipse.PartiallyResolved;
    equals(value: Ellipse): boolean;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): Ellipse.JSON;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Ellipse {
    type Canonical = Ellipse<Radius.Canonical, Position.Canonical>;
    type PartiallyResolved = Ellipse<Radius.PartiallyResolved, Position.PartiallyResolved>;
    interface JSON extends BasicShape.JSON<"ellipse"> {
        rx: Radius.JSON;
        ry: Radius.JSON;
        center: Position.JSON;
    }
    type Resolver = Radius.Resolver & Position.Resolver;
    type PartialResolver = Radius.PartialResolver & Position.PartialResolver;
    function isEllipse(value: unknown): value is Ellipse;
    const parse: CSSParser<Ellipse>;
}
//# sourceMappingURL=ellipse.d.ts.map